# sampler.py - Convert raw audio samples to GB format

import sys, getopt, struct
assert str is not bytes, "Python 3 is required to run this script."

global GBSSongPointers

def ReadByte():
	return(ord(infile.read(1)))
	
def swap(x):
	return((x & 0x0F)<<4|(x & 0xF0)>>4)

def main(argv):
	# set up stack
	global stack
	stack = []
	
	#misc vars
	inputfile = ''
	outputfile = ''
	argc = len(sys.argv)
	print("GB Sampler by DevEd")
	try:
		opts, args = getopt.getopt(argv,"hi:o:",["ifile=","ofile="])
	except getopt.GetoptError:
		print("Usage: sampler.py -i <inputfile> -o <outputfile>")
		sys.exit(2)
	
	# the above doesn't work if there are less than the expected number of arguments for some reason
	if argc != 5:
		print("Usage: sampler.py -i <inputfile> -o <outputfile>")
		sys.exit()
	
	for opt, arg in opts:
		if opt == '-h':
			print("Usage: sampler.py -i <inputfile> -o <outputfile>")
			sys.exit()
		elif opt in ("-i", "--ifile"):
			inputfile = arg
		elif opt in ("-o", "--ofile"):
			outputfile = arg
		 
	# Start of actual code

	# open files for access
	try:
		global infile
		infile = open(inputfile, "rb")
	except FileNotFoundError:
		print("ERROR:", inputfile, "doesn't exist")
		sys.exit(2)
	try:
		global outfile
		outfile = open(outputfile, "wb")
	except:
		print("Failed to open",outputfile)
		sys.exit(2)
	print("Opened", infile.name)
	
	# verify file
	if infile.read(4) != b'RIFF':
		print("ERROR: This is not a .WAV file!")
		exit(1)
	# verify sample
	infile.seek(22)
	if ord(infile.read(1)) != 1:
		print("ERROR: Sample must be mono")
		exit(1)
	
	infile.seek(24)
	if struct.unpack('i',infile.read(4))[0] != 8192:
		print("ERROR: Sample rate must be 8192 Hz")
		exit(1)
	
	infile.seek(34)
	if ord(infile.read(1)) != 8:
		print("ERROR: Sample must be 8-bit unsigned")
		
	infile.seek(44)
			
	z=[]
	s=0
	while 1:
		try:
			x=ord(infile.read(1))&0xf0
			y=swap(ord(infile.read(1))&0xf0)
			z.append(x+y)
			s=s+1
		except TypeError:
			break;
	outfile.write(bytes(z))
	
	padsize = ((s // 16) * 16) + 16
	for i in range(0, padsize - s):
		outfile.write(bytes([0x77]))
	
	print("Conversion complete.\n\nSample size:",padsize//1024,"\bK (",'\b'+str(padsize),"\b bytes)")
	if s>16384:
		print("Warning: Sample is larger than 16K.")
	
	infile.close()
	outfile.close()

if __name__ == "__main__":
	main(sys.argv[1:])
	
