;-------------
; Starting Screen
; BANK1 ADDR ()
; BYTES USED = 
;-------------

;-------------
; c = continuous
; e = at the end
;
; BEHAVIOUR
; 1 - Set RAM used to 0
; 2 - Load initial INITIAL_TILE_DATA and MapInitial
; 3 - rLCY set to $10 (at level of sun)
; 4 - Load sprites to RAM
; 5 - Turn counter on
; 5 - STATE 3
;   c - Move airplane from right side of the screen to left side until it disapears
;   c - Fade in background and sprite palletes
;   c - Once faded in completely, turn off counter1
;   e - Add %11110010 to vy of volleyball (hit ball)
;   e - Turn on counter1
; 6 - STATE 4
;   c - Simulate ball physics (add gravity and mirror sprites) going up until apex
;   c - Once apex reaches, wait for some time
;   c - Once wait is over, apply physics to ball again and make camera go down 
;   c - at $90, set ball and sand dune at very bottom of screen
;   c - After rLCY $90, begin blanking the lines with $FF to make way for the shiba_net map and move volleyball and dune up
;   e - Change to BG8600 MODE to target shiba_net
;   e - Turn off counter1
; 7 - STATE 5
;   c - Parallax top and bottom of screen until bottom rSCX is at $60
;   c - Move ball and dune left as the bottom of screen parallaxes
;   e - Set tongue X position to match with incoming shiba
; 8 - STATE 6
;   c - Parallax top and bottom as MapDog is loaded vertically in $C800 until bottom rSCX reaches 0
;   c - Scroll tongue X to the left
;   e - Load the rest of MapDog that's beyond rSCX $60
;   e - Set wCounter1 to 0
; 9 - STATE 7
;   c - Parallax top and bottom and begin blanking with $FF to make way for DogDisplay until rSCX 0
;   c - Scroll tongue until it reaches left end of screen
;   e - Load the tiles for DogDisplay
;   e - blank what's beyond $60
; 10 - STATE 8
;   c - Parallax top and bottom until rSCY is $60
; 11 - STATE 9
;   c - Parallax top and bottom as MapDogDisplay is loaded vertically in $C800 until bottom rSCX reaches 0
;   c - Scroll tongue X to the left
;   e - Turn on counter1 and set to 0
; 12 - STATE 10
;   c - Load the MapDogDisplayOn at wCounter1 intervals to simulate the display flickering
;-------------

INCLUDE "include/defines.asm"

SECTION "Starting Screen Code",ROMX[$4000]

OBJECTS_ARRAY_SIZE EQU 10*2
LCDY_TOP_SCREEN EQU $00
LCDY_BOTTOM_SCREEN EQU $40

LoadStartingScreen::
    xor a
    ldh [hOBP1],a
    ldh [hBGP],a 	 ;setup palettes
    ldh [hOBP0],a 	 ;setup palettes
    ldh [hCurrentScreenStateRoutineIndex], a
    ld [wTongueOffsetPointer], a
    ld [wScrollXBottom], a
    ld [wScrollXTop], a
    ld [wCounter1], a                                ; Set used RAM to 0
    ld [wCounter2], a
    ld [wCounter1Off], a
    ld [wGOVolleyball_vy], a
    ld [wIsSongPlaying], a
    ld [hSCY], a
    ;rst MemsetSmall

    ld a, $01
    ld [wCounter2Off], a

    INCLUDE "res/tpnk_dev_logo_tiles.2bpp.pb16.size"
    ld b, NB_PB16_BLOCKS
    ld de, TPNK_DEV_TILE_DATA
    ld hl, _VRAM
    call pb16_unpack_block
    PURGE NB_PB16_BLOCKS

    ld de, MapTPNKDevLogo
    ld hl,  $9800
    lb bc, 20, 18
    ld a, MapTPNKDevLogoWidth
    call LCDMemcpySquare

    ld a, LCDCF_ON | LCDCF_BGON | LCDCF_BG8000 | LCDCF_OBJ16 | LCDCF_OBJON
	ldh [hLCDC], a
	ldh [rLCDC], a

    ; Enable sound globally
    ld a, $80
    ld [rAUDENA], a
    ; Enable all channels in stereo
    ld a, $FF
    ld [rAUDTERM], a
    ; Set volume
    ld a, $77
    ld [rAUDVOL], a

    xor a
    ld  [SamplePlaying],a

    ld    a,IEF_TIMER | IEF_VBLANK
    ldh   [rIE],a
    ld a   ,6
    ldh   [rTAC], a 

    ld hl, starting_screen_song
    call hUGE_init
	
    .loadAirplane:
        ld de, GOAirplane                                   ; rom data of object
        ld hl, wGOAirplane                                  ; ram instance of object
        ld bc, wGOAirplaneOAM
        call LoadSprite

    .loadVolleyball:
        ld de, GOVolleyball                                   ; rom data of object
        ld hl, wGOVolleyball                                  ; ram instance of object
        ld bc, wGOVolleyballOAM
        call LoadSprite

    .loadSand:
        ld de, GOSand                                         ; rom data of object
        ld hl, wGOSand                                ; ram instance of object
        ld bc, wGOSandOAM
        call LoadSprite

    .loadTongue:
        ld de, GOTongue                                   ; rom data of object
        ld hl, wGOTongue                                  ; ram instance of object
        ld bc, wGOTongueOAM
        call LoadSprite


    

    ret

StartingScreenLoop::
    ld a, [hCurrentScreenStateRoutineIndex]	
	ld hl, screenStateRoutineArray
	call CallRoutinePointerArray

    .moveTongue
        ld a, [wTongueOffsetPointer]
        inc a

        cp TongueOffsetTable.end-TongueOffsetTable-1
        jr nz, .keepPointer
        .setPointerStartTable:
            xor a
        .keepPointer:
            ld [wTongueOffsetPointer], a
            ld b, a

            ld hl, TongueOffsetTable

            ld a, l
            add b
            
            ld l, a         ;ld l, a
            adc h           ;ld a, h
            sub l           ;adc 0


            ld h, a

            ld a, [hl]
            ld c, a
            ld hl, wGOTongueOAM_sprite_1_1_y
            ld b, GOTongueNumSprites
            call ScrollGameObject 


    .counter1:
        ld a, [wCounter1Off]
        or a
        jr nz, .counter2
        ld a, [wCounter1]
        add 1
        ld [wCounter1], a
    .counter2:
        ld a, [wCounter2Off]
        or a
        jr nz, .playMusic
        ld a, [wCounter2]
        add 1
        ld [wCounter2], a
    
    .playMusic:
        ld a, [wIsSongPlaying]
        cp 1
        ret nz
        call _hUGE_dosound
    ret

State1:
    ld a, [wCounter2]
    cp 0
    jr z, .fadeIn
    cp 80
    jr z, .startCounter
    jr nc, .fadeOut
    ret

    .fadeIn:
        call FadeIn
        ld a, [wCounter1Off]
        cp $01
        jr z, .startTimer
        ret
    .startCounter:
        xor a
        ld [wCounter1Off], a
        ld [wCounter1], a

        ld a, $01
        ld [wCounter2Off], a
        ld a, 171
        ld [wCounter2], a
    .fadeOut:
        call FadeOut
        ld a, [wCounter1Off]
        cp $01
        jr z, .state1State2
        ret
    .startTimer:
        xor a
        ld [wCounter2Off], a
        ret
    .state1State2:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        .restartCounter1:
            xor a
            ld [wCounter1Off], a
            ld [wCounter1], a
            ld [wCounter2], a
        .stopCounter1:
            ld a, $01
            ld [wCounter2Off], a
        .includeInitialTileMapData
            ld a, [hLCDC]
            xor LCDCF_ON
            ldh [hLCDC], a
            ldh [rLCDC], a

            INCLUDE "res/title_1_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            ld de, TITLE_1_TILE_DATA
            ld hl, _VRAM
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS

            INCLUDE "res/title_2_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            ;ld de, TITLE_2_TILE_DATA
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS
    
            ld de, MapTitle
            lb bc, 20 , 18
            ld hl, _SCRN0
            ld a, MapTitleWidth
            call LCDMemcpySquare
    
            ld a, [hLCDC]
            xor LCDCF_ON
            ldh [hLCDC], a
            ldh [rLCDC], a
    ret

State2:
    ld a, [wCounter2]
    cp 0
    jr z, .fadeIn
    cp 180
    jr z, .startCounter
    jr nc, .fadeOut
    ret

    .fadeIn:
        call FadeIn
        ld a, [wCounter1Off]
        cp $01
        jr z, .startTimer
        ret
    .startCounter:
        xor a
        ld [wCounter1Off], a
        ld [wCounter1], a

        ld a, $01
        ld [wCounter2Off], a
        ld a, 181
        ld [wCounter2], a
    .fadeOut:
        call FadeOut
        ld a, [wCounter1Off]
        cp $01
        jr z, .state1State2
        ret
    .startTimer:
        xor a
        ld [wCounter2Off], a
        ret
    .state1State2:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        .restartCounter1:
            xor a
            ld [wCounter1Off], a
            ld [wCounter1], a
            ld [wCounter2], a
        .stopCounter1:
            ld a, $01
            ld [wCounter2Off], a
        .includeInitialTileMapData
            ld a, [hLCDC]
            xor LCDCF_ON
            ldh [hLCDC], a
            ldh [rLCDC], a

            INCLUDE "res/sprites_0_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            ld de, INITIAL_TILE_DATA
            ld hl, _VRAM
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS
            INCLUDE "res/sprites_1_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS
            INCLUDE "res/beach_crowd_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS
            INCLUDE "res/shiba_net_tiles.2bpp.pb16.size"
            ld b, NB_PB16_BLOCKS
            call pb16_unpack_block
            PURGE NB_PB16_BLOCKS
    
            ld de, MapInitial
            ld bc, MapInitialWidth * MapInitialHeight
            ld hl, _SCRN0
            call Memcpy
    
            ld a, [hLCDC]
            xor LCDCF_ON
            ldh [hLCDC], a
            ldh [rLCDC], a

            xor  a
            call PlaySample
    ret

State3:
    .checkPlaneLeftScreen:
        ld a, [wGOAirplaneOAM_sprite_1_5_x]																		
        cp $00
        jr nz, .fadeIn

    .state1State2:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a
        
        xor a                                                     ; turn counter on
        ld [wCounter1Off], a
        ld [wCounter1], a

        .hit_ball:
            ld a, %11110010 ; -10
            ld [wGOVolleyball_vy], a

        .hitBallSound:
            ld a, $3A
            ld [rNR41], a
            ld a,  $F1
            ld [rNR42], a
            ld a, $70
            ld [rNR43], a
            ld a, $80
            ld [rNR44], a

        ret

    .fadeIn:
        ld a, [wCounter1Off]
        cp 1
        jr z, .movePlane
        call FadeIn

    .movePlane:
        ld hl, wGOAirplaneOAM_sprite_1_1_x
        lb bc, GOAirplaneNumSprites, %11111110	
        call ScrollGameObject
        ;SCROLL_SPRITE_X 5, plane, %11111110	

    ret

State4:
    ld a, [wGOVolleyball_attrs]
    rlca
	jr c, .cameraFollow

    ld a, [wGOVolleyball_vy]																
    or a
    jr nz, .moveBall

    .wait:
        ld a, [wCounter1]
        cp 140
        jr nz, .flipBall

    .moveBall:
        ld a, [wGOVolleyball_vy]
        ld c, a
        ld hl, wGOVolleyballOAM_sprite_1_1_y
        ld b, GOVolleyballNumSprites

        call ScrollGameObject

        ld a, c
		add GRAVITY
		ld [wGOVolleyball_vy], a

        and %10000000
		jr nz, .flipBall

    .ballFalling:
        ld hl, wGOVolleyballOAM
        ld a, 159
        cp [hl]

        jr z, .hitGround
        jr c, .hitGround
        jr .cameraFollow

        .hitGround:
            ld a, %10000000
            ld [wGOVolleyball_attrs], a

            ld a, $01
            ld [wIsSongPlaying], a

            inc hl
            lb de, GOVolleyballNumSpritesW, GOVolleyballNumSpritesH
            ld c, $C0
            call SetGameObjectPositionX

        .ballHitSandSound:
            ld a, $3A
            ld [rNR41], a
            ld a,  $F1
            ld [rNR42], a
            ld a, $02
            ld [rNR43], a
            ld a, $80
            ld [rNR44], a
    ret

    .flipBall
        ld a, [wCounter1]
        and %00000111
        jr z, .flip
        ret
        .flip:
            ld hl, wGOVolleyballOAM
            lb bc, GOVolleyballNumSprites, OAMF_YFLIP
            call TOGGLE_OAM_FLAG

            ld b, GOVolleyballNumSprites
            call ChangeTopBottom

    ret

    .cameraFollow:
        ld a, [hSCY]
        add 2
        ld [hSCY], a

        cp $70
        jr c, .flipBall

        cp $90	

        jr c, .checkReachEnd
        jr z, .setBallIntoFrame
        .moveBallIntoFrame
            ld hl, wGOVolleyballOAM_sprite_1_1_y
            lb bc, GOVolleyballNumSprites, %11111110

            call ScrollGameObject

            ld hl, wGOSandOAM_sprite_1_1_y
            ld b, GOSandNumSprites

            call ScrollGameObject

            jr .checkReachEnd
        ret
        .setBallIntoFrame
            ld hl, wGOVolleyballOAM
            lb de, GOVolleyballNumSpritesW, GOVolleyballNumSpritesH
            ld c, $9F
            call SetGameObjectPositionY

            ld hl, wGOVolleyballOAM_sprite_1_1_x
            lb de, GOVolleyballNumSpritesW, GOVolleyballNumSpritesH
            ld c, 70
            call SetGameObjectPositionX
        
        .checkReachEnd:
            ld a, [hSCY]
            cp $C0 
            jr z, .state2State3

            ld b, a
            and 7                                                       ; check if scroll is multiple of 8
            jr nz, .skipLoad
        .startOfRow:
            ld a, b
            sub $70

            add a
            add a
            ld l, a
            adc $98 ;ld a, $98
	        sub l ;adc 0

            ld h, a
            ld c, 32
            ld a, $FF
            call LCDMemsetSmall
            ;call nz, LOAD_BYTE_INTO_MAP_LINE
        .skipLoad:
            
        ;jr nc, .moveBallIntoFrame

        ret

    .state2State3:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        ld a, [hLCDC]
        xor LCDCF_BG8000
        ldh [hLCDC],a   

        ld a, $01
        ld [wCounter1Off], a

        ret
    ret

State5:
    ld a, [wGOVolleyballOAM_sprite_1_4_x]
    cp $A0
    jr nc, .parallax

    .moveBall:
        ld hl, wGOVolleyballOAM_sprite_1_1_x
        lb bc, GOVolleyballNumSprites, %11111100	
        call ScrollGameObject

        ld hl, wGOSandOAM_sprite_1_1_x
        lb bc, GOSandNumSprites, %11111100	
        call ScrollGameObject

    .parallax:
        call Parallax
        ld a, [wScrollXBottom]
        ;add 4
        cp $60
        jr z, .state3State4
    ret 

    .state3State4:
        ld hl, wGOTongueOAM_sprite_1_1_x
        lb de, GOTongueNumSpritesW, GOTongueNumSpritesH
        ld c, $C4
        call SetGameObjectPositionX

        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        ld hl, screenStateRoutineArray
        call CallRoutinePointerArray

        .disableHBlankInterrupt:
            ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
            ld  [rIE],a

            ld a, STATF_MODE01
            ldh [rSTAT],a
    ret

State6:
    ld a, [wScrollXBottom]
    ld b, a
    and 7
    ld a, b
    jr z, .startOfColumn
	jr .parallax

    .startOfColumn:
        sub $60
        REPT 3 ; divide by 8
            rrca
        ENDR
        and %00011111

        ld b, a
        ld de, MapDog
        add e

        ld e, a ;ld e, a
        adc d   ;ld a, d
        sub e   ;adc 0

        ld d, a
        cp HIGH(MapDog + MapDogWidth)
	    jr c, .loadDogLine
        ld a, e
        cp LOW(MapDog + MapDogWidth)
	    jr c, .loadDogLine
        jr .parallax
    
    .loadDogLine:
        ld a, b
        
        add $00
        ld b, a
        adc $98 ;ld a, $98
        sub b ;adc 0
        ld h, a
        ld a, b

        cp 32
        jr nc, .overflowRight
        jr .noOverflowRight
        .overflowRight:
            add %11100000
        .noOverflowRight:
        ld l, a

        lb bc, MapDogWidth, MapDogHeight

        call LCDMemcpyVertical

    .parallax:
        call Parallax
        ld a, [wScrollXBottom]
        ;add 4
        or a
        jr z, .state4State5

        .scrollTongueX
            ld hl, wGOTongueOAM_sprite_1_1_x
            lb bc, GOTongueNumSprites, %11111100
            call ScrollGameObject 

        ret  
    .state4State5:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        ;ld a, $B8
        ;ld [rSCX], a
        ;ld [hSCX], a

        xor a
        ld  [wCounter1Off], a
        ld  [wCounter1], a
        ld [wScrollXBottom], a
        ld [wScrollXTop], a

        ; @param de Pointer to beginning of block to copy
        ; @param hl Pointer to where to copy (bytes will be written from there onwards)
        ; @param b width of square
        ; @param c height of square
        ; @param a width of source data
        ld de, MapDog + 6*30 + 22
        ld hl,  $98D4
        lb bc, 8, 3
        ld a, MapDogWidth
        call LCDMemcpySquare
        ; 5F9D


        .disableHBlankInterrupt:
            ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
            ld  [rIE],a

            ld a, STATF_MODE01
            ldh [rSTAT],a
    ret

State7:
    ld a, [wCounter1]
    cp 190
    jr nz, .wait
    ld a, $01
    ld [wCounter1Off], a

    ld a, [wScrollXBottom]
    cp $60
    jr c, .parallax
    ld b, a
    and 7
    ld a, b
    jr z, .startOfColumn
	jr .parallax

    .startOfColumn:
        sub $60
        REPT 3 ; divide by 8
            rrca
        ENDR
        and %00011111
        
        add $00
        
        ld b, a
        adc $98 ;ld a, $98
        sub b ;adc 0

        ld h, a
        ld a, b

        cp 32
        jr nc, .overflowRight
        jr .noOverflowRight
        .overflowRight:
            add %11100000
        .noOverflowRight:
        ld l, a

        ld c, MapDogHeight
        ld a, $FF

        call LCDMemsetSmallVertical

    .parallax
        call Parallax
        ld a, [wScrollXBottom]
        or a
        jr z, .state5State6

        ld a, [wGOTongueOAM_sprite_1_2_x]
        cp $A0
        ret nc
        .scrollTongueX
            ld hl, wGOTongueOAM_sprite_1_1_x
            lb bc, GOTongueNumSprites, %11111100
            call ScrollGameObject 

            ret  

    .wait:
    ret 

    .state5State6
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        .load_dog_display_map:
            ld de, DOG_DISPLAY_TILE_DATA
            ld bc, DOG_DISPLAY_TILE_DATA.end - DOG_DISPLAY_TILE_DATA
            ld hl, _VRAM9000
            call LCDMemcpy

        .blank_rest:
            ld d, $FF
            ld hl, $98D4
            lb bc, $07, $03

            call LCDMemsetSquare

    .disableHBlankInterrupt:
            ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
            ld  [rIE],a

            ld a, STATF_MODE01
            ldh [rSTAT],a
    ret


State8: ; SCROLLX RIGHT FROM $00 to $00       
    .parallax
        call Parallax
        ld a, [wScrollXBottom]
        cp $60
        jr z, .state6State7
        ret  

    .state6State7
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        .disableHBlankInterrupt:
            ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
            ld  [rIE],a

            ld a, STATF_MODE01
            ldh [rSTAT],a
    ret
State9:
    ld a, [wScrollXBottom]
    ld b, a
    and 7
    ld a, b
    jr z, .startOfColumn
	jr .parallax

    .startOfColumn:
        sub $60
        REPT 3 ; divide by 8
            rrca
        ENDR
        and %00011111

        ld b, a
        ld de, MapDogDisplay
        add e

        ld e, a ;ld e, a
        adc d   ;ld a, d
        sub e   ;adc 0

        ld d, a
        cp HIGH(MapDogDisplay + MapDogDisplayWidth)
	    jr c, .loadDogLine
        ld a, e
        cp LOW(MapDogDisplay + MapDogDisplayWidth)
	    jr c, .loadDogLine
        jr .parallax
    
    .loadDogLine:
        ld a, b
        
        add $00

        ld b, a
        adc $98 ;ld a, $98
	    sub b ;adc 0

        ld h, a
        ld a, b

        cp 32
        jr nc, .overflowRight
        jr .no_overflowRight
        .overflowRight:
            add %11100000
        .no_overflowRight:
        ld l, a

        lb bc, MapDogDisplayWidth, MapDogDisplayHeight

        call LCDMemcpyVertical

    .parallax:
        call Parallax
        ld a, [wScrollXBottom]
        ;add 4
        or a
        jr z, .state7State8
        ret  

    .state7State8:
        ld a, [hCurrentScreenStateRoutineIndex]
        inc a 
        ld [hCurrentScreenStateRoutineIndex], a

        xor a
        ld [wCounter1Off], a
        ld [wCounter1], a

        .disableHBlankInterrupt:
            ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
            ld  [rIE],a

            ld a, STATF_MODE01
            ldh [rSTAT],a
    ret

State10:
    ld a, [wCounter1]
    cp 50
    jr z, .turnOnDisplay
    cp 90
    jr z, .turnOffDisplay
    cp 140
    jr z, .turnOnDisplay
    cp 180
    jr z, .turnOffDisplay
    cp 230
    jr z, .turnOnDisplay
    inc a
    jr z, .turnOffDisplay
    ret

    .turnOffDisplay
        ld de, MapDogDisplay + 5 * 20 + 5
        ld hl,  $98A5
        ld b, MapDogDisplayWidth
        ld c, MapDogDisplayHeight
        ld a, MapDogDisplayWidth
        call LCDMemcpySquare
    ret
    .turnOnDisplay
        ld de, MapDisplayOn
        ld hl,  $98A5
        ld b, MapDisplayOnWidth
        ld c, MapDisplayOnHeight
        ld a, MapDisplayOnWidth
        call LCDMemcpySquare

    ret

Parallax:													
    .enableHBlankInterrupt:
        ld  a,IEF_LCDC 
        ld  [rIE],a

        ld  a, STATF_LYC
        ld  [rSTAT], a       	
    .waitHBlank
        ld a, [wScrollXBottom]
        add 4
        ld [wScrollXBottom], a
        ld c, a

        ld a, [wScrollXTop]
        add %11111100
        ld [wScrollXTop], a
        ld b, a

        ld a, LCDY_TOP_SCREEN
        ld [rLYC], a

        halt

        ld a, b
        ld [rSCX], a

        ld a, LCDY_BOTTOM_SCREEN
        ld [rLYC], a

        halt

        ld a, c
        ld [rSCX], a

        ;ld a, $90
        ;ld [rLYC], a

        ;halt																
    .disableHBlankInterrupt:
        ld  a,IEF_VBLANK | IEF_TIMER ;enable vblank interrupt
        ld  [rIE],a

        ld a, STATF_MODE01
        ldh [rSTAT],a
    ret

FadeIn:																	; 1 - Fade in at ScrollX and ScrollY 0
    ld  a,[wCounter1]
    cp 20																   	 
    ret c
    cp 30
    jr c, .fadeIn1
    cp 40
    jr c, .fadeIn2
    cp 100
    jr z, .turnOffCounter 
    jr .fadeIn3

    .fadeIn1:
        ld  a,%01000000
        ldh [hBGP],a
        ldh [hOBP0],a 	
        ret

    .fadeIn2:
        ld  a,%10010000
        ldh [hBGP],a
        ldh [hOBP0],a 
        ret

    .turnOffCounter 
        ld a, $01
        ld [wCounter1Off], a
        xor a
        ld [wCounter1], a
        ;NR41-44
        ;3A,F1,71,80

    .fadeIn3:
        ld  a,%11100100 
        ldh [hBGP],a 
        ldh [hOBP0],a 
    ret

FadeOut:																	; 1 - Fade in at ScrollX and ScrollY 0
    ld  a,[wCounter1]
    cp 20																   	 
    ret c
    cp 30
    jr c, .fadeIn1
    cp 40
    jr c, .fadeIn2
    cp 100
    jr z, .turnOffCounter 
    jr .fadeIn3

    .fadeIn1:
        ld  a,%11100100 
        ldh [hBGP],a 
        ldh [hOBP0],a 

    .fadeIn2:
        ld  a,%10010000
        ldh [hBGP],a
        ldh [hOBP0],a 
        ret

    .turnOffCounter 
        ld a, $01
        ld [wCounter1Off], a
        xor a
        ld [wCounter1], a
        ;NR41-44
        ;3A,F1,71,80

    .fadeIn3:
        ld  a,%00000000
        ldh [hBGP],a
        ldh [hOBP0],a 	
    ret
;-------------
; Screen Data
;-------------

SECTION "Screen state routine array",ROMX
screenStateRoutineArray: ; 128 functions max
   dw State1, State2, State3, State4, State5, State6, State7, State8, State9, State10

SECTION "Sprite data",ROMX
    game_object_rom Airplane, 1, 5, $60,$A8,$34,$00
    game_object_rom Volleyball, 2, 4, $A0 ,$48,$00,$00
    game_object_rom Sand, 1, 3, $B7, $46, $3E, %10010000
    game_object_rom Tongue, 2, 2, $78,$F0,$14, %00000000
TongueOffsetTable:
DB $00, $00, $00, $00, $01, $00, $01, $00, $00, $00, $00, $FF, $00, $FF, $00
.end

SECTION "Starting screen tiles", ROMX    

TPNK_DEV_TILE_DATA:
    INCBIN "res/starting_screen/tpnk_dev_logo/tpnk_dev_logo_tiles.2bpp.pb16" 
.end

TITLE_1_TILE_DATA:
    INCBIN "res/title_1_tiles.2bpp.pb16" 
.end
TITLE_2_TILE_DATA:
    INCBIN "res/title_2_tiles.2bpp.pb16" 
.end

INITIAL_TILE_DATA:
    INCBIN "res/sprites_0_tiles.2bpp.pb16"   
    INCBIN "res/sprites_1_tiles.2bpp.pb16"   
    INCBIN "res/beach_crowd_tiles.2bpp.pb16"   
    INCBIN "res/shiba_net_tiles.2bpp.pb16"     
.end

DOG_DISPLAY_TILE_DATA:
INCBIN "res/starting_screen/dog_display_tiles.2bpp" 
.end

SECTION "Maps",ROMX 
    map_rom TPNKDevLogo, 20,18
    INCBIN "res/starting_screen/tpnkdev_logo.map"  
    map_rom Title, 20,18
    INCBIN "res/starting_screen/title.map"  
    map_rom Initial, 32,32
    INCBIN "res/starting_screen/initial.map"   
    map_rom Dog, 30,10
    INCBIN "res/starting_screen/shiba_net.map"
    map_rom DogDisplay, 20,10
    INCBIN "res/starting_screen/dog_display.map"
    map_rom DisplayOn, 10,3
    INCBIN "res/starting_screen/display_on.map"

;-------------
; Screen Variables
;-------------
SECTION "Starting screen variables", WRAM0   
wCounter1Off:
ds 1  
wCounter1:
ds 1
wCounter2Off:
ds 1
wCounter2:
ds 1
wScrollXBottom:
ds 1
wScrollXTop:
ds 1
wIsSongPlaying:
ds 1

;-------------
; Game Object Variables
;-------------
SECTION "Game Object Variables",WRAM0
    game_object_ram Airplane
    game_object_ram Volleyball
    game_object_ram Sand

    game_object_ram Tongue
wTongueOffsetPointer:
db

SECTION "Routine pointer Index", HRAM
hCurrentScreenStateRoutineIndex:
db

;-------------
; Shadow OAM
;-------------
SECTION UNION "Shadow OAM", WRAM0,ALIGN[8]; But it can be HRAM, WRAMX, or SRAM, too!
    dstruct OEM1X3, wGOSandOAM
    dstruct OEM1X5, wGOAirplaneOAM
    dstruct OEM2X4, wGOVolleyballOAM
    dstruct OEM2X2, wGOTongueOAM


